@@ -180,7 +180,7 @@ void TasksModel::Private::initModels()
                          }
 
                          if (roles.contains(AbstractTasksModel::IsActive)) {
-                             emit q->activeTaskChanged();
+                             Q_EMIT q->activeTaskChanged();
                          }
 
                          // In manual sort mode, updateManualSortMap() may consult the sortRowInsertQueue
@@ -1056,7 +1056,7 @@ void TasksModel::updateLauncherCount()
 
     if (d->launcherCount != count) {
         d->launcherCount = count;
-        emit launcherCountChanged();
+        Q_EMIT launcherCountChanged();
     }
 }
 
@@ -1218,7 +1218,7 @@ void TasksModel::setSortMode(SortMode mode)
 
         d->forceResort();
 
-        emit sortModeChanged();
+        Q_EMIT sortModeChanged();
     }
 }
 
@@ -1235,7 +1235,7 @@ void TasksModel::setSeparateLaunchers(bool separate)
         d->updateManualSortMap();
         d->forceResort();
 
-        emit separateLaunchersChanged();
+        Q_EMIT separateLaunchersChanged();
     }
 }
 
@@ -1251,7 +1251,7 @@ void TasksModel::setLaunchInPlace(bool launchInPlace)
 
         d->forceResort();
 
-        emit launchInPlaceChanged();
+        Q_EMIT launchInPlaceChanged();
     }
 }
 
@@ -1288,7 +1288,7 @@ void TasksModel::setGroupInline(bool groupInline)
 
         d->updateGroupInline();
 
-        emit groupInlineChanged();
+        Q_EMIT groupInlineChanged();
     }
 }
 
@@ -1306,7 +1306,7 @@ void TasksModel::setGroupingWindowTasksThreshold(int threshold)
             d->groupingProxyModel->setWindowTasksThreshold(threshold);
         }
 
-        emit groupingWindowTasksThresholdChanged();
+        Q_EMIT groupingWindowTasksThresholdChanged();
     }
 }
 
