@@ -34,6 +34,11 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
     , m_shellSurface(nullptr)
 {
     QObject::setParent(corona);
+    // Some people reported that setColor(Qt::black) breaks panel translucency on X11. Needs more investigation.
+    if (KWindowSystem::isPlatformWayland()) {
+        setColor(Qt::black);
+    }
+
     if (targetScreen) {
         setScreenToFollow(targetScreen);
         setScreen(targetScreen);
@@ -67,6 +72,7 @@ void DesktopView::showEvent(QShowEvent *e)
 
 void DesktopView::setScreenToFollow(QScreen *screen)
 {
+    Q_ASSERT(screen);
     if (screen == m_screenToFollow) {
         return;
     }
@@ -122,7 +128,7 @@ void DesktopView::setWindowType(DesktopView::WindowType type)
 
     adaptToScreen();
 
-    emit windowTypeChanged();
+    Q_EMIT windowTypeChanged();
 }
 
 void DesktopView::ensureWindowType()
@@ -321,7 +327,7 @@ void DesktopView::screenGeometryChanged()
     if (m_shellSurface) {
         m_shellSurface->setPosition(geo.topLeft());
     }
-    emit geometryChanged();
+    Q_EMIT geometryChanged();
 }
 
 void DesktopView::coronaPackageChanged(const KPackage::Package &package)
