@@ -130,7 +130,6 @@ bool isSessionVariable(const QByteArray &name)
 void setEnvironmentVariable(const QByteArray &name, const QByteArray &value)
 {
     if (qgetenv(name) != value) {
-        //        qCDebug(PLASMA_STARTUP) << "setting..." << env.left(idx) << env.mid(idx+1) << "was" << qgetenv(env.left(idx));
         qputenv(name, value);
     }
 }
@@ -228,7 +227,7 @@ void setupCursor(bool wayland)
     qputenv("XCURSOR_SIZE", QByteArray::number(kcminputrc_mouse_cursorsize));
 }
 
-std::optional<QStringList> getSystemdEnvironment()
+std::optional<QProcessEnvironment> getSystemdEnvironment()
 {
     QStringList list;
     auto msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
@@ -251,7 +250,16 @@ std::optional<QStringList> getSystemdEnvironment()
         return std::nullopt;
     }
 
-    return variant.toStringList();
+    const auto assignmentList = variant.toStringList();
+    QProcessEnvironment ret;
+    for (auto &env : assignmentList) {
+        const int idx = env.indexOf(QLatin1Char('='));
+        if (Q_LIKELY(idx > 0)) {
+            ret.insert(env.left(idx), env.mid(idx + 1));
+        }
+    }
+
+    return ret;
 }
 
 // Import systemd user environment.
@@ -260,23 +268,16 @@ std::optional<QStringList> getSystemdEnvironment()
 // But it won't work if plasma is not started by systemd.
 void importSystemdEnvrionment()
 {
-    auto environment = getSystemdEnvironment();
+    const auto environment = getSystemdEnvironment();
     if (!environment) {
         return;
     }
 
-    for (auto &envString : environment.value()) {
-        const auto env = envString.toLocal8Bit();
-        const int idx = env.indexOf('=');
-        if (Q_UNLIKELY(idx <= 0)) {
-            continue;
+    for (auto &nameStr : environment.value().keys()) {
+        const auto name = nameStr.toLocal8Bit();
+        if (!isShellVariable(name) && !isSessionVariable(name)) {
+            setEnvironmentVariable(name, environment.value().value(nameStr).toLocal8Bit());
         }
-
-        const auto name = env.left(idx);
-        if (isShellVariable(name) || isSessionVariable(name)) {
-            continue;
-        }
-        setEnvironmentVariable(name, env.mid(idx + 1));
     }
 }
 
@@ -414,7 +415,7 @@ void setupX11()
     runSync(QStringLiteral("xsetroot"), {QStringLiteral("-cursor_name"), QStringLiteral("left_ptr")});
 }
 
-void cleanupPlasmaEnvironment(const std::optional<QStringList> &oldSystemdEnvironment)
+void cleanupPlasmaEnvironment(const std::optional<QProcessEnvironment> &oldSystemdEnvironment)
 {
     qunsetenv("KDE_FULL_SESSION");
     qunsetenv("KDE_SESSION_VERSION");
@@ -429,16 +430,6 @@ void cleanupPlasmaEnvironment(const std::optional<QStringList> &oldSystemdEnviro
         return;
     }
 
-    QStringList vars;
-    for (auto &env : currentEnv.value()) {
-        const int idx = env.indexOf(QLatin1Char('='));
-        if (Q_UNLIKELY(idx <= 0)) {
-            continue;
-        }
-
-        vars.append(env.left(idx));
-    }
-
     // According to systemd documentation:
     // If a variable is listed in both, the variable is set after this method returns, i.e. the set list overrides the unset list.
     // So this will effectively restore the state to the values in oldSystemdEnvironment.
@@ -446,17 +437,49 @@ void cleanupPlasmaEnvironment(const std::optional<QStringList> &oldSystemdEnviro
                                                           QStringLiteral("/org/freedesktop/systemd1"),
                                                           QStringLiteral("org.freedesktop.systemd1.Manager"),
                                                           QStringLiteral("UnsetAndSetEnvironment"));
-    message.setArguments({vars, oldSystemdEnvironment.value()});
+    message.setArguments({currentEnv.value().keys(), oldSystemdEnvironment.value().toStringList()});
 
     // The session program gonna quit soon, ensure the message is flushed.
     auto reply = QDBusConnection::sessionBus().asyncCall(message);
     reply.waitForFinished();
 }
 
+// Drop session-specific variables from the systemd environment.
+// Those can be leftovers from previous sessions, which can interfere with the session
+// we want to start now, e.g. $DISPLAY might break kwin_wayland.
+static void dropSessionVarsFromSystemdEnvironment()
+{
+    const auto environment = getSystemdEnvironment();
+    if (!environment) {
+        return;
+    }
+
+    QStringList varsToDrop;
+    for (auto &nameStr : environment.value().keys()) {
+        // If it's set in this process, it'll be overwritten by the following UpdateLaunchEnvJob
+        const auto name = nameStr.toLocal8Bit();
+        if (!qEnvironmentVariableIsSet(name) && isSessionVariable(name)) {
+            varsToDrop.append(nameStr);
+        }
+    }
+
+    auto msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
+                                              QStringLiteral("/org/freedesktop/systemd1"),
+                                              QStringLiteral("org.freedesktop.systemd1.Manager"),
+                                              QStringLiteral("UnsetEnvironment"));
+    msg << varsToDrop;
+    auto reply = QDBusConnection::sessionBus().call(msg);
+    if (reply.type() == QDBusMessage::ErrorMessage) {
+        qWarning() << "Failed to unset systemd environment variables:" << reply.errorName() << reply.errorMessage();
+    }
+}
+
 // kwin_wayland can possibly also start dbus-activated services which need env variables.
 // In that case, the update in startplasma might be too late.
 bool syncDBusEnvironment()
 {
+    dropSessionVarsFromSystemdEnvironment();
+
     // At this point all environment variables are set, let's send it to the DBus session server to update the activation environment
     auto job = new UpdateLaunchEnvJob(QProcessEnvironment::systemEnvironment());
     return job->exec();
@@ -524,7 +547,7 @@ bool useSystemdBoot()
         return false;
     }
 
-    if (!hasSystemdService(QStringLiteral("plasma-workspace@.target"))) {
+    if (!hasSystemdService(QStringLiteral("plasma-workspace.target"))) {
         qWarning() << "Systemd boot requested, but plasma services were not found";
         return false;
     }
@@ -555,6 +578,50 @@ void startKSplashViaSystemd()
     }
 }
 
+static void migrateUserScriptsAutostart()
+{
+    QDir configLocation(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
+    QDir autostartScriptsLocation(configLocation.filePath(QStringLiteral("autostart-scripts")));
+    if (!autostartScriptsLocation.exists()) {
+        return;
+    }
+    const QDir autostartScriptsMovedLocation(configLocation.filePath(QStringLiteral("old-autostart-scripts")));
+    const auto entries = autostartScriptsLocation.entryInfoList(QDir::Files);
+    for (const auto &info : entries) {
+        const auto scriptName = info.fileName();
+        const auto scriptPath = info.absoluteFilePath();
+        const auto scriptMovedPath = autostartScriptsMovedLocation.filePath(scriptName);
+
+        // Don't migrate backup files
+        if (scriptName.endsWith(QLatin1Char('~')) || scriptName.endsWith(QLatin1String(".bak"))
+            || (scriptName[0] == QLatin1Char('%') && scriptName.endsWith(QLatin1Char('%')))
+            || (scriptName[0] == QLatin1Char('#') && scriptName.endsWith(QLatin1Char('#')))) {
+            qCDebug(PLASMA_STARTUP) << "Not migrating backup autostart script" << scriptName;
+            continue;
+        }
+
+        // Migrate autostart script to a standard .desktop autostart file
+        AutostartScriptDesktopFile desktopFile(scriptName, info.isSymLink() ? info.symLinkTarget() : scriptMovedPath);
+        qCInfo(PLASMA_STARTUP) << "Migrated legacy autostart script" << scriptPath << "to" << desktopFile.fileName();
+
+        if (info.isSymLink() && QFile::remove(scriptPath)) {
+            qCInfo(PLASMA_STARTUP) << "Removed legacy autostart script" << scriptPath << "that pointed to" << info.symLinkTarget();
+        }
+    }
+    // Delete or rename autostart-scripts to old-autostart-scripts to avoid running the migration again
+    if (autostartScriptsLocation.entryInfoList(QDir::Files).empty()) {
+        autostartScriptsLocation.removeRecursively();
+    } else {
+        configLocation.rename(autostartScriptsLocation.dirName(), autostartScriptsMovedLocation.dirName());
+    }
+    // Reload systemd so that the XDG autostart generator is run again to pick up the new .desktop files
+    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
+                                                          QStringLiteral("/org/freedesktop/systemd1"),
+                                                          QStringLiteral("org.freedesktop.systemd1.Manager"),
+                                                          QStringLiteral("Reload"));
+    QDBusConnection::sessionBus().call(message);
+}
+
 bool startPlasmaSession(bool wayland)
 {
     resetSystemdFailedUnits();
@@ -634,7 +701,7 @@ bool startPlasmaSession(bool wayland)
                                                   QStringLiteral("/org/freedesktop/systemd1"),
                                                   QStringLiteral("org.freedesktop.systemd1.Manager"),
                                                   QStringLiteral("StartUnit"));
-        msg << QStringLiteral("plasma-workspace@%1.target").arg(platform) << QStringLiteral("fail");
+        msg << QStringLiteral("plasma-workspace-%1.target").arg(platform) << QStringLiteral("fail");
         QDBusReply<QDBusObjectPath> reply = QDBusConnection::sessionBus().call(msg);
         if (!reply.isValid()) {
             qWarning() << "Could not start systemd managed Plasma session:" << reply.error().name() << reply.error().message();
@@ -680,50 +747,6 @@ void waitForKonqi()
     }
 }
 
-static void migrateUserScriptsAutostart()
-{
-    QDir configLocation(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation));
-    QDir autostartScriptsLocation(configLocation.filePath(QStringLiteral("autostart-scripts")));
-    if (!autostartScriptsLocation.exists()) {
-        return;
-    }
-    const QDir autostartScriptsMovedLocation(configLocation.filePath(QStringLiteral("old-autostart-scripts")));
-    const auto entries = autostartScriptsLocation.entryInfoList(QDir::Files);
-    for (const auto &info : entries) {
-        const auto scriptName = info.fileName();
-        const auto scriptPath = info.absoluteFilePath();
-        const auto scriptMovedPath = autostartScriptsMovedLocation.filePath(scriptName);
-
-        // Don't migrate backup files
-        if (scriptName.endsWith(QLatin1Char('~')) || scriptName.endsWith(QLatin1String(".bak"))
-            || (scriptName[0] == QLatin1Char('%') && scriptName.endsWith(QLatin1Char('%')))
-            || (scriptName[0] == QLatin1Char('#') && scriptName.endsWith(QLatin1Char('#')))) {
-            qCDebug(PLASMA_STARTUP) << "Not migrating backup autostart script" << scriptName;
-            continue;
-        }
-
-        // Migrate autostart script to a standard .desktop autostart file
-        AutostartScriptDesktopFile desktopFile(scriptName, info.isSymLink() ? info.symLinkTarget() : scriptMovedPath);
-        qCInfo(PLASMA_STARTUP) << "Migrated legacy autostart script" << scriptPath << "to" << desktopFile.fileName();
-
-        if (info.isSymLink() && QFile::remove(scriptPath)) {
-            qCInfo(PLASMA_STARTUP) << "Removed legacy autostart script" << scriptPath << "that pointed to" << info.symLinkTarget();
-        }
-    }
-    // Delete or rename autostart-scripts to old-autostart-scripts to avoid running the migration again
-    if (autostartScriptsLocation.entryInfoList(QDir::Files).empty()) {
-        autostartScriptsLocation.removeRecursively();
-    } else {
-        configLocation.rename(autostartScriptsLocation.dirName(), autostartScriptsMovedLocation.dirName());
-    }
-    // Reload systemd so that the XDG autostart generator is run again to pick up the new .desktop files
-    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.systemd1"),
-                                                          QStringLiteral("/org/freedesktop/systemd1"),
-                                                          QStringLiteral("org.freedesktop.systemd1.Manager"),
-                                                          QStringLiteral("Reload"));
-    QDBusConnection::sessionBus().call(message);
-}
-
 void playStartupSound(QObject *parent)
 {
     KNotifyConfig notifyConfig(QStringLiteral("plasma_workspace"), QList<QPair<QString, QString>>(), QStringLiteral("startkde"));
